@@ -1,10 +1,10 @@
 from office365.communications.callrecords.call_record import CallRecord
 from office365.communications.calls.call import Call
-from office365.communications.onlinemeetings.online_meeting_collection import OnlineMeetingCollection
+from office365.communications.onlinemeetings.collection import OnlineMeetingCollection
 from office365.communications.presences.presence import Presence
 from office365.entity import Entity
 from office365.entity_collection import EntityCollection
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 
 
