@@ -1,13 +1,14 @@
-from office365.communications.onlinemeetings.online_meeting_collection import OnlineMeetingCollection
+from office365.communications.onlinemeetings.collection import OnlineMeetingCollection
 from office365.communications.presences.presence import Presence
+from office365.delta_collection import DeltaCollection
 from office365.directory.extensions.extension import Extension
 from office365.directory.licenses.assigned_plan import AssignedPlan
-from office365.directory.users.user_settings import UserSettings
+from office365.directory.users.settings import UserSettings
 from office365.onedrive.sites.site import Site
 from office365.onenote.onenote import Onenote
 from office365.outlook.calendar.attendee_base import AttendeeBase
 from office365.outlook.calendar.calendar import Calendar
-from office365.outlook.calendar.calendar_group import CalendarGroup
+from office365.outlook.calendar.group import CalendarGroup
 from office365.outlook.calendar.event import Event
 from office365.outlook.calendar.meeting_time_suggestions_result import MeetingTimeSuggestionsResult
 from office365.outlook.calendar.reminder import Reminder
@@ -17,23 +18,28 @@ from office365.directory.directory_object_collection import DirectoryObjectColle
 from office365.directory.licenses.license_details import LicenseDetails
 from office365.directory.identities.object_identity import ObjectIdentity
 from office365.directory.profile_photo import ProfilePhoto
-from office365.entity_collection import EntityCollection, DeltaCollection
+from office365.entity_collection import EntityCollection
 from office365.outlook.contacts.contact import Contact
-from office365.outlook.contacts.contact_folder import ContactFolder
-from office365.outlook.mail.mail_folder import MailFolder
+from office365.outlook.contacts.folder import ContactFolder
+from office365.outlook.mail.folder import MailFolder
 from office365.onedrive.drives.drive import Drive
 from office365.outlook.mail.mailbox_settings import MailboxSettings
+from office365.outlook.mail.messages.collection import MessageCollection
 from office365.outlook.mail.messages.message import Message
-from office365.outlook.outlook_user import OutlookUser
-from office365.planner.planner_user import PlannerUser
+from office365.outlook.mail.recipient import Recipient
+from office365.outlook.user import OutlookUser
+from office365.planner.user import PlannerUser
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.http.http_method import HttpMethod
+from office365.runtime.paths.entity import EntityPath
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.types.collections import StringCollection
-from office365.teams.team_collection import TeamCollection
+from office365.teams.chats.collection import ChatCollection
+from office365.teams.collection import TeamCollection
 from office365.teams.user_teamwork import UserTeamwork
+from office365.todo.todo import Todo
 
 
 class User(DirectoryObject):
@@ -66,19 +72,27 @@ class User(DirectoryObject):
         self.context.add_query(qry)
         return self
 
-    def send_mail(self, message, save_to_sent_items=False):
+    def send_mail(self, subject, body, to_recipients, save_to_sent_items=False):
         """Send a new message on the fly
 
-        :type message: office365.mail.message.Message
-        :type save_to_sent_items: bool
+        :param str subject: The subject of the message.
+        :param str body: The body of the message. It can be in HTML or text format
+        :param list[str] to_recipients: The To: recipients for the message.
+        :param bool save_to_sent_items: Indicates whether to save the message in Sent Items. Specify it only if
+            the parameter is false; default is true
         """
+        message = Message(self.context)
+        message.subject = subject
+        message.body = body
+        [message.to_recipients.add(Recipient.from_email(email)) for email in to_recipients]
+
         payload = {
             "message": message,
             "saveToSentItems": save_to_sent_items
         }
         qry = ServiceOperationQuery(self, "sendmail", None, payload)
         self.context.add_query(qry)
-        return self
+        return message
 
     def export_personal_data(self, storage_location):
         """
@@ -214,10 +228,18 @@ class User(DirectoryObject):
         """True if the account is enabled; otherwise, false. This property is required when a user is created."""
         return self.properties.get('accountEnabled', None)
 
+    @property
+    def chats(self):
+        """The user's chats."""
+        return self.properties.get('chats',
+                                   ChatCollection(self.context, ResourcePath("chats", self.resource_path)))
+
     @property
     def given_name(self):
         """
         The given name (first name) of the user. Maximum length is 64 characters.
+
+        :rtype: str or None
         """
         return self.properties.get('givenName', None)
 
@@ -279,14 +301,12 @@ class User(DirectoryObject):
            May contain multiple items with the same signInType value.
            Supports $filter.
         """
-        return self.properties.get('identities',
-                                   ClientValueCollection(ObjectIdentity))
+        return self.properties.get('identities', ClientValueCollection(ObjectIdentity))
 
     @property
     def assigned_licenses(self):
         """The licenses that are assigned to the user, including inherited (group-based) licenses. """
-        return self.properties.get('assignedLicenses',
-                                   ClientValueCollection(AssignedLicense))
+        return self.properties.get('assignedLicenses', ClientValueCollection(AssignedLicense))
 
     @property
     def followed_sites(self):
@@ -360,12 +380,9 @@ class User(DirectoryObject):
 
     @property
     def drive(self):
-        """Retrieve the properties and relationships of a Drive resource.
-
-        :rtype: Drive
-        """
-        return self.get_property('drive',
-                                 Drive(self.context, ResourcePath("drive", self.resource_path)))
+        """Retrieve the properties and relationships of a Drive resource."""
+        return self.properties.get('drive',
+                                   Drive(self.context, EntityPath("drive", self.resource_path, ResourcePath("drives"))))
 
     @property
     def contacts(self):
@@ -392,8 +409,7 @@ class User(DirectoryObject):
     def messages(self):
         """Get an event collection or an event."""
         return self.properties.get('messages',
-                                   DeltaCollection(self.context, Message,
-                                                   ResourcePath("messages", self.resource_path)))
+                                   MessageCollection(self.context, ResourcePath("messages", self.resource_path)))
 
     @property
     def joined_teams(self):
@@ -453,9 +469,9 @@ class User(DirectoryObject):
 
         :rtype: EntityCollection
         """
-        return self.get_property('extensions',
-                                 EntityCollection(self.context, Extension,
-                                                  ResourcePath("extensions", self.resource_path)))
+        return self.properties.get('extensions',
+                                   EntityCollection(self.context, Extension,
+                                                    ResourcePath("extensions", self.resource_path)))
 
     @property
     def direct_reports(self):
@@ -464,9 +480,9 @@ class User(DirectoryObject):
 
         :rtype: EntityCollection
         """
-        return self.get_property('directReports',
-                                 DirectoryObjectCollection(self.context,
-                                                           ResourcePath("directReports", self.resource_path)))
+        return self.properties.get('directReports',
+                                   DirectoryObjectCollection(self.context,
+                                                             ResourcePath("directReports", self.resource_path)))
 
     @property
     def online_meetings(self):
@@ -475,9 +491,9 @@ class User(DirectoryObject):
 
         :rtype: OnlineMeetingCollection
         """
-        return self.get_property('onlineMeetings',
-                                 OnlineMeetingCollection(self.context,
-                                                         ResourcePath("onlineMeetings", self.resource_path)))
+        return self.properties.get('onlineMeetings',
+                                   OnlineMeetingCollection(self.context,
+                                                           ResourcePath("onlineMeetings", self.resource_path)))
 
     @property
     def presence(self):
@@ -491,12 +507,19 @@ class User(DirectoryObject):
         return self.properties.get('teamwork',
                                    UserTeamwork(self.context, ResourcePath("teamwork", self.resource_path)))
 
+    @property
+    def todo(self):
+        """Represents the To Do services available to a user."""
+        return self.properties.get('todo',
+                                   Todo(self.context, ResourcePath("todo", self.resource_path)))
+
     def get_property(self, name, default_value=None):
         if default_value is None:
             property_mapping = {
                 "businessPhones": self.business_phones,
                 "calendarGroups": self.calendar_groups,
                 "contactFolders": self.contact_folders,
+                "followedSites": self.followed_sites,
                 "licenseDetails": self.license_details,
                 "memberOf": self.member_of,
                 "transitiveMemberOf": self.transitive_member_of,
@@ -514,5 +537,5 @@ class User(DirectoryObject):
         # fallback: create a new resource path
         if self._resource_path is None:
             if name == "id" or name == "userPrincipalName":
-                self._resource_path = ResourcePath(value, self._parent_collection.resource_path)
+                self._resource_path = ResourcePath(value, self.parent_collection.resource_path)
         return self
