@@ -1,4 +1,5 @@
 from office365.runtime.client_object import ClientObject
+from office365.runtime.paths.entity import EntityPath
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.queries.delete_entity import DeleteEntityQuery
 from office365.runtime.queries.update_entity import UpdateEntityQuery
@@ -29,8 +30,10 @@ class Entity(ClientObject):
 
     @property
     def entity_type_name(self):
-        name = type(self).__name__
-        return "microsoft.graph." + name[0].lower() + name[1:]
+        if self._entity_type_name is None:
+            name = type(self).__name__
+            self._entity_type_name = "microsoft.graph." + name[0].lower() + name[1:]
+        return self._entity_type_name
 
     @property
     def id(self):
@@ -43,10 +46,10 @@ class Entity(ClientObject):
         super(Entity, self).set_property(name, value, persist_changes)
         if name == "id":
             if self._resource_path is None:
-                if type(self.parent_collection.resource_path) is ResourcePath:
-                    self._resource_path = ResourcePath(value, self.parent_collection.resource_path)
-                else:
+                if isinstance(self.parent_collection.resource_path, EntityPath):
                     self._resource_path = self.parent_collection.resource_path.normalize(value)
-            else:
+                else:
+                    self._resource_path = ResourcePath(value, self.parent_collection.resource_path)
+            elif isinstance(self._resource_path, EntityPath):
                 self._resource_path.normalize(value, inplace=True)
         return self
