@@ -1,22 +1,27 @@
 from office365.communications.cloud_communications import CloudCommunications
+from office365.delta_collection import DeltaCollection
 from office365.directory.applications.application import Application
 from office365.directory.applications.application_template import ApplicationTemplate
 from office365.directory.applications.service_principal import ServicePrincipal
-from office365.directory.audit.audit_log_root import AuditLogRoot
+from office365.directory.audit.log_root import AuditLogRoot
 from office365.directory.directory import Directory
 from office365.directory.directory_object_collection import DirectoryObjectCollection
-from office365.directory.groups.group_collection import GroupCollection
-from office365.directory.groups.group_lifecycle_policy import GroupLifecyclePolicy
-from office365.directory.groups.group_setting_template import GroupSettingTemplate
+from office365.directory.groups.collection import GroupCollection
+from office365.directory.groups.lifecycle_policy import GroupLifecyclePolicy
+from office365.directory.groups.setting_template import GroupSettingTemplate
 from office365.directory.identities.identity_container import IdentityContainer
 from office365.directory.identities.identity_provider import IdentityProvider
+from office365.directory.internal.paths.me import MePath
 from office365.directory.licenses.subscribed_sku import SubscribedSku
 from office365.directory.organizations.org_contact import OrgContact
 from office365.directory.organizations.organization import Organization
+from office365.directory.policies.root import PolicyRoot
 from office365.directory.subscriptions.subscription import Subscription
 from office365.directory.users.user import User
-from office365.directory.users.user_collection import UserCollection
-from office365.entity_collection import EntityCollection, DeltaCollection
+from office365.directory.users.collection import UserCollection
+from office365.education.root import EducationRoot
+from office365.entity_collection import EntityCollection
+from office365.external.external import External
 from office365.onedrive.drives.drive import Drive
 from office365.onedrive.shares.shares_collection import SharesCollection
 from office365.onedrive.sites.sites_with_root import SitesWithRoot
@@ -26,17 +31,17 @@ from office365.reports.report_root import ReportRoot
 from office365.runtime.auth.token_response import TokenResponse
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.http.http_method import HttpMethod
-from office365.runtime.odata.odata_request import ODataRequest
+from office365.runtime.odata.request import ODataRequest
 from office365.runtime.odata.v4.batch_request import ODataV4BatchRequest
 from office365.runtime.odata.v4.json_format import V4JsonFormat
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.runtime.queries.batch import BatchQuery
 from office365.runtime.queries.delete_entity import DeleteEntityQuery
 from office365.runtime.queries.update_entity import UpdateEntityQuery
-from office365.search.search_entity import SearchEntity
-from office365.teams.chats.chat import Chat
-from office365.teams.team_collection import TeamCollection
-from office365.teams.teams_template import TeamsTemplate
+from office365.search.entity import SearchEntity
+from office365.security.security import Security
+from office365.teams.chats.collection import ChatCollection
+from office365.teams.collection import TeamCollection
+from office365.teams.template import TeamsTemplate
 
 
 class GraphClient(ClientRuntimeContext):
@@ -62,12 +67,15 @@ class GraphClient(ClientRuntimeContext):
         self._build_specific_query(request)
         return request
 
-    def execute_batch(self):
-        """Constructs and submit a batch request"""
-        batch_request = ODataV4BatchRequest(self)
-        queries = [qry for qry in self.pending_request()]
-        batch_request.add_query(BatchQuery(self, queries))  # Aggregate requests into batch request
+    def execute_batch(self, items_per_batch=100):
+        """Constructs and submit a batch request
+
+        :param int items_per_batch: Maximum to be selected for bulk operation
+        """
+        batch_request = ODataV4BatchRequest(self, items_per_batch)
+        [batch_request.add_query(qry) for qry in self.pending_request()]
         batch_request.execute_query()
+        return self
 
     def pending_request(self):
         return self._pending_request
@@ -81,7 +89,7 @@ class GraphClient(ClientRuntimeContext):
 
         :type request: RequestOptions
         """
-        query = self.current_query
+        query = self.pending_request().current_query
         if isinstance(query, UpdateEntityQuery):
             request.method = HttpMethod.Patch
         elif isinstance(query, DeleteEntityQuery):
@@ -100,7 +108,7 @@ class GraphClient(ClientRuntimeContext):
     @property
     def me(self):
         """The Me endpoint is provided as a shortcut for specifying the current user"""
-        return User(self, ResourcePath("me"))
+        return User(self, MePath())
 
     @property
     def drives(self):
@@ -140,7 +148,7 @@ class GraphClient(ClientRuntimeContext):
     @property
     def chats(self):
         """Get teams"""
-        return EntityCollection(self, Chat, ResourcePath("chats"))
+        return ChatCollection(self, ResourcePath("chats"))
 
     @property
     def group_setting_templates(self):
@@ -247,3 +255,26 @@ class GraphClient(ClientRuntimeContext):
         The search endpoint is the entry point for Microsoft Search API to query data.
         """
         return SearchEntity(self, ResourcePath("search"))
+
+    @property
+    def education(self):
+        """
+        The /education namespace exposes functionality that is specific to the education sector.
+        """
+        return EducationRoot(self, ResourcePath("education"))
+
+    @property
+    def policies(self):
+        """Resource type exposing navigation properties for the policies singleton."""
+        return PolicyRoot(self, ResourcePath("policies"))
+
+    @property
+    def external(self):
+        """A logical container  for external sources."""
+        return External(self, ResourcePath("external"))
+
+    @property
+    def security(self):
+        """The security resource is the entry point for the Security object model.
+        It returns a singleton security resource. It doesn't contain any usable properties."""
+        return Security(self, ResourcePath("security"))
