@@ -1,3 +1,5 @@
+import os
+
 from office365.directory.subscriptions.subscription import Subscription
 from office365.onedrive.driveitems.audio import Audio
 from office365.onedrive.driveitems.geo_coordinates import GeoCoordinates
@@ -5,32 +7,31 @@ from office365.onedrive.driveitems.image import Image
 from office365.onedrive.driveitems.item_preview_info import ItemPreviewInfo
 from office365.onedrive.driveitems.photo import Photo
 from office365.onedrive.driveitems.special_folder import SpecialFolder
+from office365.onedrive.internal.queries.resumable_file_upload import create_resumable_file_upload_query
 from office365.onedrive.internal.queries.upload_content import create_upload_content_query
 from office365.base_item import BaseItem
 from office365.onedrive.analytics.item_activity_stat import ItemActivityStat
 from office365.onedrive.analytics.item_analytics import ItemAnalytics
 from office365.onedrive.permissions.permission import Permission
 from office365.entity_collection import EntityCollection
-from office365.onedrive.internal.paths.children_path import ChildrenPath
+from office365.onedrive.internal.paths.children import ChildrenPath
 from office365.onedrive.driveitems.conflict_behavior import ConflictBehavior
 from office365.onedrive.shares.shared import Shared
-from office365.onedrive.versions.drive_item_version import DriveItemVersion
+from office365.onedrive.versions.drive_item import DriveItemVersion
 from office365.onedrive.files.file import File
-from office365.onedrive.files.fileSystemInfo import FileSystemInfo
+from office365.onedrive.files.system_info import FileSystemInfo
 from office365.onedrive.folders.folder import Folder
 from office365.onedrive.listitems.list_item import ListItem
 from office365.onedrive.driveitems.publication_facet import PublicationFacet
-from office365.onedrive.internal.paths.root_path import RootPath
 from office365.onedrive.driveitems.thumbnail_set import ThumbnailSet
-from office365.onedrive.upload_session import UploadSession
 from office365.onedrive.workbooks.workbook import Workbook
-from office365.onedrive.internal.paths.url_path import UrlPath
+from office365.onedrive.internal.paths.url import UrlPath
 from office365.runtime.client_result import ClientResult
 from office365.runtime.http.http_method import HttpMethod
-from office365.runtime.queries.create_entity_query import CreateEntityQuery
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.create_entity import CreateEntityQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.runtime.paths.service_operation import ServiceOperationPath
+from office365.runtime.queries.upload_session import UploadSessionQuery
 
 
 class DriveItem(BaseItem):
@@ -53,8 +54,8 @@ class DriveItem(BaseItem):
 
         :param str link_type: The type of sharing link to create. Either view, edit, or embed.
         :param str scope:  The scope of link to create. Either anonymous or organization.
-        :param str expiration_datetime: A String with format of yyyy-MM-ddTHH:mm:ssZ of DateTime indicates the expiration
-            time of the permission.
+        :param str expiration_datetime: A String with format of yyyy-MM-ddTHH:mm:ssZ of DateTime indicates
+            the expiration time of the permission.
         :param str password: The password of the sharing link that is set by the creator. Optional
             and OneDrive Personal only.
         :param str message:
@@ -93,19 +94,16 @@ class DriveItem(BaseItem):
         Check out a driveItem resource to prevent others from editing the document, and prevent your changes
         from being visible until the documented is checked in.
         """
-        qry = ServiceOperationQuery(self,
-                                    "checkout",
-                                    None
-                                    )
+        qry = ServiceOperationQuery(self, "checkout")
         self.context.add_query(qry)
         return self
 
-    def checkin(self, comment, checkInAs=""):
+    def checkin(self, comment, checkin_as=""):
         """
         Check in a checked out driveItem resource, which makes the version of the document available to others.
 
         :param str comment: comment to the new version of the file
-        :param str checkInAs: The status of the document after the check-in operation is complete.
+        :param str checkin_as: The status of the document after the check-in operation is complete.
             Can be published or unspecified.
         """
         qry = ServiceOperationQuery(self,
@@ -113,13 +111,13 @@ class DriveItem(BaseItem):
                                     None,
                                     {
                                         "comment": comment,
-                                        "checkInAs": checkInAs
+                                        "checkInAs": checkin_as
                                     }
                                     )
         self.context.add_query(qry)
         return self
 
-    def resumable_upload(self, source_path, chunk_size=1000000, chunk_uploaded=None):
+    def resumable_upload(self, source_path, chunk_size=2000000, chunk_uploaded=None):
         """
         Create an upload session to allow your app to upload files up to the maximum file size.
         An upload session allows your app to upload ranges of the file in sequential API requests,
@@ -130,14 +128,14 @@ class DriveItem(BaseItem):
             Upload bytes to the upload session
 
         :param chunk_uploaded:
-        :param str source_path: Local file path
+        :param str source_path: File path
         :param int chunk_size: chunk size
         """
-        from office365.onedrive.internal.queries.file_upload import ResumableFileUpload
-        upload_query = ResumableFileUpload(self, source_path, chunk_size, chunk_uploaded)
-        self.children.add_child(upload_query.return_type)
-        self.context.add_query(upload_query)
-        return upload_query.return_type
+        file_name = os.path.basename(source_path)
+        return_type = DriveItem(self.context, UrlPath(file_name, self.resource_path))
+        qry = create_resumable_file_upload_query(return_type, source_path, chunk_size, chunk_uploaded)
+        self.context.add_query(qry)
+        return return_type
 
     def create_upload_session(self, item):
         """Creates a temporary storage location where the bytes of the file will be saved until the complete file is
@@ -145,18 +143,9 @@ class DriveItem(BaseItem):
 
         :type item: office365.graph.onedrive.driveItemUploadableProperties.DriveItemUploadableProperties
         """
-        result = ClientResult(self.context, UploadSession())
-        qry = ServiceOperationQuery(self,
-                                    "createUploadSession",
-                                    None,
-                                    {
-                                        "item": item
-                                    },
-                                    None,
-                                    result
-                                    )
+        qry = UploadSessionQuery(self, {"item": item})
         self.context.add_query(qry)
-        return result
+        return qry.return_type
 
     def upload(self, name, content):
         """The simple upload API allows you to provide the contents of a new file or update the contents of an
@@ -363,9 +352,7 @@ class DriveItem(BaseItem):
             "endDateTime": end_dt.strftime('%m-%d-%Y') if end_dt else None,
             "interval": interval
         }
-        return_type = EntityCollection(self.context, ItemActivityStat,
-                                       ServiceOperationPath("getActivitiesByInterval", params,
-                                                            self.resource_path))
+        return_type = EntityCollection(self.context, ItemActivityStat, self.resource_path)
         qry = ServiceOperationQuery(self, "getActivitiesByInterval", params, None, None, return_type)
         self.context.add_query(qry)
 
@@ -502,7 +489,7 @@ class DriveItem(BaseItem):
         :rtype: EntityCollection
         """
         return self.get_property('children',
-                                 EntityCollection(self.context, DriveItem, ChildrenPath(self.resource_path, "items")))
+                                 EntityCollection(self.context, DriveItem, ChildrenPath(self.resource_path)))
 
     @property
     def listItem(self):
@@ -577,12 +564,3 @@ class DriveItem(BaseItem):
             }
             default_value = property_mapping.get(name, None)
         return super(DriveItem, self).get_property(name, default_value)
-
-    def set_property(self, name, value, persist_changes=True):
-        if name == "id":
-            if self._resource_path is None:
-                self._resource_path = self.parent_collection.resource_path.normalize(value)
-            elif isinstance(self._resource_path, UrlPath):
-                self._resource_path = self._resource_path.normalize(value)
-        super(DriveItem, self).set_property(name, value, persist_changes)
-        return self
