@@ -6,9 +6,9 @@ from office365.onedrive.listitems.item_reference import ItemReference
 from office365.onedrive.permissions.sharing_invitation import SharingInvitation
 from office365.onedrive.permissions.sharing_link import SharingLink
 from office365.runtime.client_value_collection import ClientValueCollection
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.runtime.types.string_collection import StringCollection
+from office365.runtime.types.collections import StringCollection
 
 
 class Permission(Entity):
