@@ -1,43 +1,46 @@
-import copy
+import datetime
+from typing import TypeVar
 
 from office365.runtime.client_value import ClientValue
+from office365.runtime.odata.type import ODataType
 from office365.runtime.odata.v3.json_light_format import JsonLightFormat
-from office365.runtime.odata.odata_json_format import ODataJsonFormat
+from office365.runtime.odata.json_format import ODataJsonFormat
 from office365.runtime.odata.query_options import QueryOptions
 
+T = TypeVar('T', bound='ClientObject')
+P_T = TypeVar('P_T')
+
 
 class ClientObject(object):
 
-    def __init__(self, context, resource_path=None, parent_collection=None, namespace=None):
+    def __init__(self, context, resource_path=None, parent_collection=None):
         """
         Base client object which define named properties and relationships of an entity
 
         :type parent_collection: office365.runtime.client_object_collection.ClientObjectCollection or None
         :type resource_path: office365.runtime.paths.resource_path.ResourcePath or None
         :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
-        :type namespace: str
         """
         self._properties = {}
-        self._properties_metadata = {}
-        self._entity_type_name = None
+        self._ser_property_names = []
         self._query_options = QueryOptions()
         self._parent_collection = parent_collection
         self._context = context
+        self._entity_type_name = None
         self._resource_path = resource_path
-        self._namespace = namespace
-
-    def set_metadata(self, name, group, value):
-        if name not in self._properties_metadata:
-            self._properties_metadata[name] = {}
-        self._properties_metadata[name][group] = value
-
-    def get_metadata(self, name, group, default_value=None):
-        return self._properties_metadata.get(name, {}).get(group, default_value)
 
     def clear(self):
-        self._properties_metadata = {}
+        self._properties = {k: v for k, v in self._properties.items() if k not in self._ser_property_names}
+        self._ser_property_names = []
+        self._query_options = QueryOptions()
+        return self
 
     def execute_query(self):
+        """
+        Submit request(s) to the server
+
+        :type self: T
+        """
         self.context.execute_query()
         return self
 
@@ -52,16 +55,21 @@ class ClientObject(object):
         return self
 
     def build_request(self):
-        return self.context.build_request(self.context.current_query)
+        return self.context.pending_request().current_query.build_request()
 
     def get(self):
+        """
+        :type self: T
+
+        Retrieves a client object from the server
+        """
         self.context.load(self)
         return self
 
     def is_property_available(self, name):
         """Returns a Boolean value that indicates whether the specified property has been retrieved or set.
 
-        :param str name: A Property name
+        :param str name: A property name
         """
         if name in self.properties:
             return True
@@ -69,7 +77,9 @@ class ClientObject(object):
 
     def expand(self, names):
         """
+        Specifies the related resources to be included in line with retrieved resources
 
+        :type self: T
         :type names: list[str]
         """
         self.query_options.expand = names
@@ -77,9 +87,10 @@ class ClientObject(object):
 
     def select(self, names):
         """
+        Allows to request a limited set of properties
 
-        :param list[str] names:
-        :return:
+        :type self: T
+        :param list[str] names: the list of property names
         """
         self.query_options.select = names
         return self
@@ -88,13 +99,21 @@ class ClientObject(object):
         if self._parent_collection is None:
             return
         self._parent_collection.remove_child(self)
+        return self
+
+    def track_changes(self, name, value):
+        if name not in self._ser_property_names:
+            self._ser_property_names.append(name)
+            self._properties[name] = value
+        return self
 
     def get_property(self, name, default_value=None):
         """
         Gets property value
 
-        :param str name: property name
-        :param any default_value: property value
+        :type name: str
+        :type default_value: P_T
+        :rtype: P_T
         """
         if default_value is None:
             normalized_name = name[0].lower() + name[1:]
@@ -105,25 +124,27 @@ class ClientObject(object):
         """Sets property value
 
         :param str name: Property name
-        :param any value: Property value
+        :param P_T value: Property value
         :param bool persist_changes: Persist changes
         """
-        self._properties_metadata[name] = {}
         if persist_changes:
-            self.set_metadata(name, "persist", True)
+            self._ser_property_names.append(name)
 
-        prop_type = self.get_property(name)
-        if isinstance(prop_type, ClientObject) or isinstance(prop_type, ClientValue) and value is not None:
+        typed_value = self.get_property(name)
+        if isinstance(typed_value, ClientObject) or isinstance(typed_value, ClientValue):
             if isinstance(value, list):
-                [prop_type.set_property(i, v, persist_changes) for i, v in enumerate(value)]
-                self._properties[name] = prop_type
+                [typed_value.set_property(i, v, persist_changes) for i, v in enumerate(value)]
+                self._properties[name] = typed_value
             elif isinstance(value, dict):
-                [prop_type.set_property(k, v, persist_changes) for k, v in value.items()]
-                self._properties[name] = prop_type
+                [typed_value.set_property(k, v, persist_changes) for k, v in value.items()]
+                self._properties[name] = typed_value
             else:
                 self._properties[name] = value
         else:
-            self._properties[name] = value
+            if isinstance(typed_value, datetime.datetime):
+                self._properties[name] = ODataType.parse_datetime(value)
+            else:
+                self._properties[name] = value
         return self
 
     def ensure_property(self, name, action, *args, **kwargs):
@@ -145,34 +166,30 @@ class ClientObject(object):
 
         names_to_include = [n for n in names if not self.is_property_available(n)]
         if len(names_to_include) > 0:
-            from office365.runtime.queries.read_entity_query import ReadEntityQuery
+            from office365.runtime.queries.read_entity import ReadEntityQuery
             qry = ReadEntityQuery(self, names_to_include)
-            self.context.add_query(qry, set_as_current=False)
+            self.context.add_query(qry)
             self.context.after_query_execute(qry, action, *args, **kwargs)
         else:
             action(*args, **kwargs)
         return self
 
-    def clone_object(self):
-        result = copy.deepcopy(self)
-        result._context = self.context
-        return result
-
     @property
     def entity_type_name(self):
+        """Returns server type name for an entity"""
         if self._entity_type_name is None:
-            if self._namespace is None:
-                self._entity_type_name = type(self).__name__
-            else:
-                self._entity_type_name = ".".join([self._namespace, type(self).__name__])
+            self._entity_type_name = type(self).__name__
         return self._entity_type_name
 
     @property
     def resource_url(self):
         """
         Returns resource url
+
         :rtype: str or None
         """
+        if self.resource_path is None:
+            return None
         return self.context.service_root_url() + str(self.resource_path)
 
     @property
@@ -197,17 +214,25 @@ class ClientObject(object):
 
     def to_json(self, json_format=None):
         """
-        :type json_format: office365.runtime.odata.odata_json_format.ODataJsonFormat or None
+        Serializes client object
+
+        :type json_format: office365.runtime.odata.json_format.ODataJsonFormat or None
         """
-        ser_prop_names = [n for n, p in self._properties_metadata.items() if p.get("persist", False) is True]
-        json = dict((k, self.get_property(k)) for k in self.properties if k in ser_prop_names)
+        if json_format is None:
+            ser_prop_names = [n for n in self._properties.keys()]
+            include_control_info = False
+        else:
+            ser_prop_names = [n for n in self._ser_property_names]
+            include_control_info = self.entity_type_name is not None and json_format.include_control_information
+
+        json = {k: self.get_property(k) for k in self._properties if k in ser_prop_names}
         for k, v in json.items():
             if isinstance(v, ClientObject) or isinstance(v, ClientValue):
                 json[k] = v.to_json(json_format)
 
-        if json and self.entity_type_name is not None and json_format.include_control_information():
+        if json and include_control_info:
             if isinstance(json_format, JsonLightFormat):
-                json[json_format.metadata_type_tag_name] = {'type': self.entity_type_name}
+                json[json_format.metadata_type] = {'type': self.entity_type_name}
             elif isinstance(json_format, ODataJsonFormat):
-                json[json_format.metadata_type_tag_name] = "#" + self.entity_type_name
+                json[json_format.metadata_type] = "#" + self.entity_type_name
         return json
