@@ -7,19 +7,21 @@ class ClientResult(object):
 
         :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
         :type default_value: int or str or bool or office365.runtime.client_value.ClientValue
-            or office365.runtime.client_object.ClientObject
         """
         self._context = context
         self._value = default_value
 
+    def set_property(self, key, value, persist_changes=False):
+        from office365.runtime.client_value import ClientValue
+        if isinstance(self.value, ClientValue):
+            self.value.set_property(key, value, persist_changes)
+        else:
+            self._value = value
+
     @property
     def value(self):
         return self._value
 
-    @value.setter
-    def value(self, value):
-        self._value = value
-
     def execute_query(self):
         self._context.execute_query()
         return self
