@@ -52,10 +52,7 @@ class ClientQuery(object):
 
     @property
     def parameter_type(self):
-        if isinstance(self._parameter_type, dict):
-            return {k: v for k, v in self._parameter_type.items() if v is not None}
-        else:
-            return self._parameter_type
+        return self._parameter_type
 
     @property
     def return_type(self):
