@@ -1,27 +1,26 @@
 import copy
 
 from office365.runtime.auth.authentication_context import AuthenticationContext
-from office365.runtime.auth.providers.saml_token_provider import resolve_base_url
 from office365.runtime.auth.user_credential import UserCredential
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.odata.v3.json_light_format import JsonLightFormat
-from office365.runtime.odata.v3.batch_request import ODataBatchRequest
-from office365.runtime.odata.odata_request import ODataRequest
-from office365.runtime.queries.batch import BatchQuery
-from office365.runtime.queries.client_query import ClientQuery
+from office365.runtime.odata.v3.batch_request import ODataBatchV3Request
+from office365.runtime.odata.request import ODataRequest
 from office365.runtime.queries.delete_entity import DeleteEntityQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.queries.update_entity import UpdateEntityQuery
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.sharepoint.publishing.site_page_service import SitePageService
+from office365.sharepoint.portal.site_status import SiteStatus
+from office365.sharepoint.publishing.pages.service import SitePageService
 from office365.sharepoint.request_user_context import RequestUserContext
 from office365.sharepoint.sites.site import Site
 from office365.sharepoint.tenant.administration.hub_site_collection import HubSiteCollection
 from office365.sharepoint.webs.context_web_information import ContextWebInformation
 from office365.sharepoint.webs.web import Web
-from office365.runtime.compat import range_or_xrange, urlparse, is_absolute_url
+from office365.runtime.compat import urlparse, is_absolute_url, get_absolute_url
 
 
 class ClientContext(ClientRuntimeContext):
@@ -34,16 +33,12 @@ class ClientContext(ClientRuntimeContext):
         :param str base_url: Absolute Web or Site Url
         :param AuthenticationContext or None auth_context: Authentication context
         """
-        if base_url.endswith("/"):
-            base_url = base_url[:len(base_url) - 1]
-        if auth_context is None:
-            self._auth_context = AuthenticationContext(authority_url=base_url)
-        else:
-            self._auth_context = auth_context
         super(ClientContext, self).__init__()
+        if auth_context is None:
+            auth_context = AuthenticationContext(url=base_url)
+        self._auth_context = auth_context
         self._web = None
         self._site = None
-        self._base_url = base_url
         self._ctx_web_info = None
         self._pending_request = None
 
@@ -63,23 +58,23 @@ class ClientContext(ClientRuntimeContext):
         return url if relative else "".join([root_site_url, url])
 
     @staticmethod
-    def from_url(abs_url):
+    def from_url(full_url):
         """
         Constructs ClientContext from absolute Url
 
-        :param str abs_url: Absolute Url to resource
+        :param str full_url: Full Url to a resource
         :return: ClientContext
         """
-        base_url = resolve_base_url(abs_url)
-        ctx = ClientContext(base_url)
-        result = Web.get_web_url_from_page_url(ctx, abs_url)
+        root_site_url = get_absolute_url(full_url)
+        ctx = ClientContext(root_site_url)
+        result = Web.get_web_url_from_page_url(ctx, full_url)
 
         def _init_context_for_web(resp):
             """
             :type resp: requests.Response
             """
             resp.raise_for_status()
-            ctx._base_url = result.value
+            ctx._auth_context.url = result.value
 
         ctx.after_execute(_init_context_for_web)
         return ctx
@@ -101,7 +96,7 @@ class ClientContext(ClientRuntimeContext):
         """
         :type token_func: () -> TokenResponse
         """
-        self.authentication_context.register_provider(token_func)
+        self.authentication_context.with_access_token(token_func)
         return self
 
     def with_user_credentials(self, username, password, allow_ntlm=False, browser_mode=False):
@@ -113,7 +108,7 @@ class ClientContext(ClientRuntimeContext):
         :type allow_ntlm: bool
         :type browser_mode: bool
         """
-        self.authentication_context.register_provider(
+        self.authentication_context.with_credentials(
             UserCredential(username, password),
             allow_ntlm=allow_ntlm,
             browser_mode=browser_mode)
@@ -125,7 +120,7 @@ class ClientContext(ClientRuntimeContext):
 
         :type credentials: UserCredential or ClientCredential
         """
-        self.authentication_context.register_provider(credentials)
+        self.authentication_context.with_credentials(credentials)
         return self
 
     def execute_batch(self, items_per_batch=100):
@@ -134,18 +129,14 @@ class ClientContext(ClientRuntimeContext):
 
         :param int items_per_batch: Maximum to be selected for bulk operation
         """
-        batch_request = ODataBatchRequest(self)
+        batch_request = ODataBatchV3Request(self, items_per_batch)
 
         def _prepare_batch_request(request):
             self.ensure_form_digest(request)
 
         batch_request.beforeExecute += _prepare_batch_request
-
-        all_queries = [qry for qry in self.pending_request()]
-        for i in range_or_xrange(0, len(all_queries), items_per_batch):
-            queries = all_queries[i:i + items_per_batch]
-            batch_request.add_query(BatchQuery(self, queries))
-            batch_request.execute_query()
+        [batch_request.add_query(qry) for qry in self.pending_request()]
+        batch_request.execute_query()
         return self
 
     def build_request(self, query):
@@ -171,41 +162,39 @@ class ClientContext(ClientRuntimeContext):
         """
         :type request_options: RequestOptions
         """
-        if self._ctx_web_info is None or not self._ctx_web_info.is_valid:
+        if not self.context_info.is_valid:
             self._ctx_web_info = self.get_context_web_information(request_options=request_options)
         request_options.set_header('X-RequestDigest', self._ctx_web_info.FormDigestValue)
 
     def get_context_web_information(self, request_options=None):
         """Returns an ContextWebInformation object that specifies metadata about the site"""
-        request = RequestOptions("contextInfo")
+        request = RequestOptions("{0}/contextInfo".format(self.service_root_url()))
         request.method = HttpMethod.Post
         if request_options:
             request.proxies = request_options.proxies
             request.verify = request_options.verify
-        response = self.execute_request_direct(request)
+        response = self.pending_request().execute_request_direct(request)
         json = response.json()
         json_format = JsonLightFormat()
-        json_format.function_tag_name = "GetContextWebInformation"
+        json_format.function = "GetContextWebInformation"
         return_value = ContextWebInformation()
         self.pending_request().map_json(json, return_value, json_format)
         return return_value
 
     def get_context_web_information_ex(self):
         """Returns an ContextWebInformation object that specifies metadata about the site"""
-        result = ClientResult(self, ContextWebInformation())
+        return_type = ClientResult(self, ContextWebInformation())
 
         def _construct_request(request):
             """
             :type request: office365.runtime.http.request_options.RequestOptions
             """
             request.url = self.service_root_url() + "/contextInfo"
-            request.method = HttpMethod.Post
-            self.pending_request().json_format.function_tag_name = "GetContextWebInformation"
 
-        qry = ClientQuery(self, None, None, None, result)
+        qry = ServiceOperationQuery(self.web, "GetContextWebInformation", None, None, None, return_type)
         self.before_execute(_construct_request)
         self.add_query(qry)
-        return qry
+        return return_type
 
     def execute_query_with_incremental_retry(self, max_retry=5):
         """Handles throttling requests."""
@@ -239,14 +228,14 @@ class ClientContext(ClientRuntimeContext):
         :return ClientContext
         """
         ctx = copy.deepcopy(self)
-        ctx._base_url = url
+        ctx._auth_context.url = url
         ctx._ctx_web_info = None
         if clear_queries:
             ctx.clear()
         return ctx
 
     def authenticate_request(self, request):
-        self._auth_context.authenticate_request(request)
+        self.authentication_context.authenticate_request(request)
 
     def _build_modification_query(self, request):
         """
@@ -254,7 +243,7 @@ class ClientContext(ClientRuntimeContext):
 
         :type request: RequestOptions
         """
-        query = self.current_query
+        query = self.pending_request().current_query
 
         if request.method == HttpMethod.Post:
             self.ensure_form_digest(request)
@@ -267,12 +256,59 @@ class ClientContext(ClientRuntimeContext):
                 request.ensure_header("X-HTTP-Method", "MERGE")
                 request.ensure_header("IF-MATCH", '*')
 
+    def create_team_site(self, alias, title, is_public=True):
+        """Creates a modern SharePoint Team site
+
+        :param str alias: Site alias which defines site url, e.g. https://contoso.sharepoint.com/teams/{alias}
+        :param str title: Site title
+        :param bool is_public:
+        """
+        result = self.group_site_manager.create_group_ex(title, alias, is_public)
+        return_type = Site(self)
+
+        def _after_site_create(resp):
+            """
+            :type resp: requests.Response
+            """
+            resp.raise_for_status()
+            if result.value.SiteStatus == SiteStatus.Error:
+                raise ValueError(result.value.ErrorMessage)
+            elif result.value.SiteStatus == SiteStatus.Ready:
+                return_type.set_property("__siteUrl", result.value.SiteUrl)
+
+        self.after_execute(_after_site_create)
+        return return_type
+
+    def create_communication_site(self, alias, title):
+        """
+        Creates a modern SharePoint Communication site
+
+        :param str alias: Site alias which defines site url, e.g. https://contoso.sharepoint.com/sites/{alias}
+        :param str title: Site title
+        """
+        return_type = Site(self)
+        result = self.site_pages.communication_site.create(alias, title)
+
+        def _after_site_create(resp):
+            """
+            :type resp: requests.Response
+            """
+            resp.raise_for_status()
+            if result.value.SiteStatus == SiteStatus.Error:
+                raise ValueError("Site creation error")
+            elif result.value.SiteStatus == SiteStatus.Ready:
+                return_type.set_property("__siteUrl", result.value.SiteUrl)
+        self.after_execute(_after_site_create)
+        return return_type
+
     @property
     def context_info(self):
         """Returns an ContextWebInformation object that specifies metadata about the site
 
         :rtype: ContextWebInformation
         """
+        if self._ctx_web_info is None:
+            self._ctx_web_info = ContextWebInformation()
         return self._ctx_web_info
 
     @property
@@ -322,12 +358,12 @@ class ClientContext(ClientRuntimeContext):
     def profile_loader(self):
         """Alias to ProfileLoader"""
         from office365.sharepoint.userprofiles.profile_loader import ProfileLoader
-        return ProfileLoader.get_profile_loader(self)
+        return ProfileLoader(self)
 
     @property
     def lists(self):
         """Alias to ListCollection. Gets information about all lists that the current user can access."""
-        from office365.sharepoint.lists.list_collection import ListCollection
+        from office365.sharepoint.lists.collection import ListCollection
         return ListCollection(self, ResourcePath("Lists"))
 
     @property
@@ -364,10 +400,54 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.portal.theme_manager import ThemeManager
         return ThemeManager(self, ResourcePath("themeManager"))
 
+    @property
+    def taxonomy(self):
+        """Alias to TaxonomyService"""
+        from office365.sharepoint.taxonomy.service import TaxonomyService
+        return TaxonomyService(self)
+
+    @property
+    def search(self):
+        """Alias to SearchService"""
+        from office365.sharepoint.search.service import SearchService
+        return SearchService(self)
+
+    @property
+    def tenant_settings(self):
+        """Alias to TenantSettings"""
+        from office365.sharepoint.tenant.tenant_settings import TenantSettings
+        return TenantSettings.current(self)
+
+    @property
+    def tenant(self):
+        from office365.sharepoint.tenant.administration.tenant import Tenant
+        if self.is_tenant:
+            return Tenant(self)
+        else:
+            admin_ctx = self.clone(self.tenant_url)
+            return Tenant(admin_ctx)
+
+    @property
+    def tenant_url(self):
+        root_url = get_absolute_url(self.base_url)
+        if "-admin." in root_url:
+            return root_url
+        result = urlparse(self.base_url)
+        names = str(result.netloc).split(".")
+        names[0] = names[0] + "-admin"
+        return result.scheme + "://" + ".".join(names)
+
+    @property
+    def is_tenant(self):
+        """
+        Determines whether the current site is a tenant administration site
+        """
+        return self.tenant_url == self.base_url
+
     @property
     def base_url(self):
         """Represents absolute Web or Site Url"""
-        return self._base_url
+        return self.authentication_context.url
 
     @property
     def authentication_context(self):
