@@ -1,10 +1,9 @@
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.contenttypes.content_type_id import ContentTypeId
 from office365.sharepoint.contenttypes.field_link_collection import FieldLinkCollection
-from office365.sharepoint.fields.field_collection import FieldCollection
+from office365.sharepoint.fields.collection import FieldCollection
 
 
 class ContentType(BaseEntity):
@@ -25,10 +24,12 @@ class ContentType(BaseEntity):
         Updates the content type, and any child objects  of the content type if specified,
         with any changes made to the content type.
 
-        :param bool update_children:
+        :param bool update_children: Specifies whether changes propagate to child objects of the content type.
         """
-        qry = ServiceOperationQuery(self, "Update", [update_children])
-        self.context.add_query(qry)
+        super(ContentType, self).update()
+        if update_children:
+            qry = ServiceOperationQuery(self, "Update", [update_children])
+            self.context.add_query(qry)
         return self
 
     @property
@@ -59,6 +60,13 @@ class ContentType(BaseEntity):
         """
         self.set_property("Name", value)
 
+    @property
+    def new_form_client_side_component_properties(self):
+        """
+        :rtype: str or None
+        """
+        return self.properties.get("NewFormClientSideComponentProperties", None)
+
     @property
     def description(self):
         """Gets the description of the content type.
@@ -69,13 +77,15 @@ class ContentType(BaseEntity):
     @description.setter
     def description(self, value):
         """Sets the description of the content type.
-        :rtype: str or None
+
+        :type value: str
         """
         self.set_property("Description", value)
 
     @property
     def group(self):
         """Gets the group of the content type.
+
         :rtype: str or None
         """
         return self.properties.get("Group", None)
@@ -83,13 +93,15 @@ class ContentType(BaseEntity):
     @group.setter
     def group(self, value):
         """Sets the group of the content type.
-        :rtype: str or None
+
+        :type value: str
         """
         self.set_property("Group", value)
 
     @property
     def schema_xml(self):
         """Specifies the XML schema that represents the content type.
+
         :rtype: str or None
         """
         return self.properties.get("SchemaXml", None)
@@ -121,6 +133,5 @@ class ContentType(BaseEntity):
         super(ContentType, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
         if name == "StringId" and self._resource_path is None:
-            self._resource_path = ServiceOperationPath(
-                "getById", [value], self._parent_collection.resource_path)
+            self._resource_path = self.parent_collection.get_by_id(value).resource_path
         return self
