@@ -1,4 +1,4 @@
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.directory.user import User
@@ -10,7 +10,7 @@ class DirectorySession(BaseEntity):
 
     @property
     def me(self):
-        return self.properties.get('me', User(self.context, ResourcePath("me", self.resource_path)))
+        return self.properties.get('Me', User(self.context, ResourcePath("Me", self.resource_path)))
 
     def get_graph_user(self, principal_name):
         """
