@@ -8,13 +8,14 @@ from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.files.version_event import FileVersionEvent
 from office365.sharepoint.internal.queries.download_file import create_download_file_query
 from office365.sharepoint.base_entity import BaseEntity
+from office365.sharepoint.permissions.irm.effective_settings import EffectiveInformationRightsManagementSettings
+from office365.sharepoint.permissions.irm.settings import InformationRightsManagementSettings
 from office365.sharepoint.principal.user import User
 from office365.sharepoint.files.version_collection import FileVersionCollection
 from office365.sharepoint.listitems.listitem import ListItem
-from office365.sharepoint.permissions.irm import InformationRightsManagementSettings, \
-    EffectiveInformationRightsManagementSettings
-from office365.sharepoint.webparts.limited_webpart_manager import LimitedWebPartManager
+from office365.sharepoint.webparts.limited_manager import LimitedWebPartManager
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
+from office365.sharepoint.webparts.personalization_scope import PersonalizationScope
 
 
 class AbstractFile(BaseEntity):
@@ -255,15 +256,15 @@ class File(AbstractFile):
         self.context.add_query(qry)
         return self
 
-    def get_limited_webpart_manager(self, scope):
+    def get_limited_webpart_manager(self, scope=PersonalizationScope.User):
         """Specifies the control set used to access, modify, or add Web Parts associated with this Web Part Page and
-        view. """
+        view.
+
+        :param int scope:  Specifies the personalization scope value that depicts how Web Parts are viewed on the
+            Web Part Page.
+        """
         return LimitedWebPartManager(self.context,
-                                     ServiceOperationPath(
-                                         "GetLimitedWebPartManager",
-                                         [scope],
-                                         self.resource_path
-                                     ))
+                                     ServiceOperationPath("GetLimitedWebPartManager", [scope], self.resource_path))
 
     def open_binary_stream(self):
         """Opens the file as a stream."""
@@ -394,12 +395,13 @@ class File(AbstractFile):
         :type server_relative_url: str
         :type content: str
         """
-        url = r"web/getFileByServerRelativePath(DecodedUrl='{0}')/\$value".format(server_relative_url)
+        url = r"{0}/web/getFileByServerRelativePath(DecodedUrl='{1}')/\$value".format(context.service_root_url(),
+                                                                                      server_relative_url)
         request = RequestOptions(url)
         request.method = HttpMethod.Post
         request.set_header('X-HTTP-Method', 'PUT')
         request.data = content
-        response = context.execute_request_direct(request)
+        response = context.pending_request().execute_request_direct(request)
         return response
 
     @staticmethod
@@ -411,10 +413,11 @@ class File(AbstractFile):
         :type server_relative_url: str
         :return Response
         """
-        url = r"web/getFileByServerRelativePath(DecodedUrl='{0}')/\$value".format(server_relative_url)
+        url = r"{0}/web/getFileByServerRelativePath(DecodedUrl='{1}')/\$value".format(context.service_root_url(),
+                                                                                      server_relative_url)
         request = RequestOptions(url)
         request.method = HttpMethod.Get
-        response = context.execute_request_direct(request)
+        response = context.pending_request().execute_request_direct(request)
         return response
 
     def download(self, file_object):
