@@ -1,25 +1,29 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.base_entity_collection import BaseEntityCollection
-from office365.sharepoint.changes.change_collection import ChangeCollection
-from office365.sharepoint.changes.change_query import ChangeQuery
-from office365.sharepoint.comments.comment_collection import CommentCollection
-from office365.sharepoint.fields.field_lookup_value import FieldLookupValue
-from office365.sharepoint.fields.fieldMultiLookupValue import FieldMultiLookupValue
+from office365.sharepoint.changes.collection import ChangeCollection
+from office365.sharepoint.changes.query import ChangeQuery
+from office365.sharepoint.comments.collection import CommentCollection
+from office365.sharepoint.fields.lookup_value import FieldLookupValue
+from office365.sharepoint.fields.multi_lookup_value import FieldMultiLookupValue
 from office365.sharepoint.likes.liked_by_information import LikedByInformation
+from office365.sharepoint.listitems.compliance_info import ListItemComplianceInfo
 from office365.sharepoint.listitems.form_update_value import ListItemFormUpdateValue
-from office365.sharepoint.listitems.list_item_version import ListItemVersion
+from office365.sharepoint.listitems.version import ListItemVersion
 from office365.sharepoint.permissions.securable_object import SecurableObject
 from office365.sharepoint.reputationmodel.reputation import Reputation
-from office365.sharepoint.sharing.externalSharingSiteOption import ExternalSharingSiteOption
+from office365.sharepoint.sharing.external_sharing_site_option import ExternalSharingSiteOption
 from office365.sharepoint.sharing.object_sharing_information import ObjectSharingInformation
+from office365.sharepoint.sharing.share_link_request import ShareLinkRequest
+from office365.sharepoint.sharing.share_link_response import ShareLinkResponse
+from office365.sharepoint.sharing.share_link_settings import ShareLinkSettings
 from office365.sharepoint.sharing.sharing_result import SharingResult
-from office365.sharepoint.taxonomy.taxonomy_field_value import TaxonomyFieldValueCollection
-from office365.sharepoint.ui.applicationpages.client_people_picker import (
-    ClientPeoplePickerWebServiceInterface, ClientPeoplePickerQueryParameters
+from office365.sharepoint.taxonomy.field_value import TaxonomyFieldValueCollection
+from office365.sharepoint.ui.applicationpages.peoplepicker.web_service_interface import (
+    ClientPeoplePickerWebServiceInterface
 )
 
 
@@ -38,6 +42,51 @@ class ListItem(SecurableObject):
         if parent_list is not None:
             self.set_property("ParentList", parent_list, False)
 
+    def share_link(self, link_kind, expiration=None):
+        """Creates a tokenized sharing link for a list item based on the specified parameters and optionally
+        sends an email to the people that are listed in the specified parameters.
+
+        :param int link_kind: The kind of the tokenized sharing link to be created/updated or retrieved.
+        :param datetime or None expiration: A date/time string for which the format conforms to the ISO 8601:2004(E)
+            complete representation for calendar date and time of day and which represents the time and date of expiry
+            for the tokenized sharing link. Both the minutes and hour value MUST be specified for the difference
+            between the local and UTC time. Midnight is represented as 00:00:00. A null value indicates no expiry.
+            This value is only applicable to tokenized sharing links that are anonymous access links.
+        """
+        result = ClientResult(self.context, ShareLinkResponse())
+        payload = ShareLinkRequest(settings=ShareLinkSettings(link_kind=link_kind, expiration=expiration))
+        qry = ServiceOperationQuery(self, "ShareLink", None, payload, "request", result)
+        self.context.add_query(qry)
+        return result
+
+    def unshare_link(self, link_kind, share_id=None):
+        """
+        Removes the specified tokenized sharing link of the list item.
+
+        :param int link_kind: This optional value specifies the globally unique identifier (GUID) of the tokenized
+            sharing link that is intended to be removed.
+        :param str or None share_id: The kind of tokenized sharing link that is intended to be removed.
+        """
+        payload = {"linkKind": link_kind, "shareId": share_id}
+        qry = ServiceOperationQuery(self, "UnshareLink", None, payload)
+        self.context.add_query(qry)
+        return self
+
+    def delete_link_by_kind(self, link_kind):
+        """Removes the specified tokenized sharing link of the list item
+
+        :param int link_kind: The kind of tokenized sharing link that is intended to be removed.
+            This MUST be set to one of the following values:
+            OrganizationView (section 3.2.5.315.1.3)
+            OrganizationEdit (section 3.2.5.315.1.4)
+            AnonymousView (section 3.2.5.315.1.5)
+            AnonymousEdit (section 3.2.5.315.1.6)
+        """
+        payload = {"linkKind": link_kind}
+        qry = ServiceOperationQuery(self, "DeleteLinkByKind", None, payload)
+        self.context.add_query(qry)
+        return self
+
     def set_rating(self, value):
         """
         Rates an item within the specified list. The return value is the average rating for the specified list item.
@@ -49,6 +98,7 @@ class ListItem(SecurableObject):
 
         def _list_item_loaded():
             Reputation.set_rating(self.context, self.parent_list.id, self.id, value, return_value)
+
         self.parent_list.ensure_properties(["Id", "ParentList"], _list_item_loaded)
         return return_value
 
@@ -64,6 +114,7 @@ class ListItem(SecurableObject):
 
         def _list_item_loaded():
             Reputation.set_like(self.context, self.parent_list.id, self.id, value, return_value)
+
         self.parent_list.ensure_properties(["Id", "ParentList"], _list_item_loaded)
         return return_value
 
@@ -115,28 +166,27 @@ class ListItem(SecurableObject):
         :rtype: SharingResult
         """
 
-        result = ClientResult(self.context, SharingResult(self.context))
-        file_result = ClientResult(self.context)
-
+        return_type = SharingResult(self.context)
         role_values = {
             ExternalSharingSiteOption.View: "role:1073741826",
             ExternalSharingSiteOption.Edit: "role:1073741827",
         }
 
-        def _property_resolved():
-            file_result.value = self.get_property("EncodedAbsUrl")
-
-        def _picker_value_resolved(picker_value):
+        def _picker_value_resolved(resp, picker_result):
+            file_abs_url = self.get_property("EncodedAbsUrl")
+            picker_value = "[{0}]".format(picker_result.value)
             from office365.sharepoint.webs.web import Web
-            result.value = Web.share_object(self.context, file_result.value, picker_value, role_values[share_option],
-                                            0,
-                                            False, send_email, False, email_subject, email_body)
+            Web.share_object(self.context, file_abs_url, picker_value, role_values[share_option],
+                             0, False, send_email, False, email_subject, email_body, return_type=return_type)
+
+        def _property_resolved():
+            picker_result = ClientPeoplePickerWebServiceInterface.client_people_picker_resolve_user(self.context,
+                                                                                                    user_principal_name)
+            self.context.after_execute(_picker_value_resolved, True, picker_result)
 
         self.ensure_property("EncodedAbsUrl", _property_resolved)
-        params = ClientPeoplePickerQueryParameters(user_principal_name)
-        ClientPeoplePickerWebServiceInterface.client_people_picker_resolve_user(self.context,
-                                                                                params, _picker_value_resolved)
-        return result.value
+
+        return return_type
 
     def unshare(self):
         """
@@ -144,15 +194,15 @@ class ListItem(SecurableObject):
 
         :rtype: SharingResult
         """
-        result = ClientResult(self.context, SharingResult(self.context))
+        return_type = SharingResult(self.context)
 
         def _property_resolved():
             abs_url = self.get_property("EncodedAbsUrl")
             from office365.sharepoint.webs.web import Web
-            result.value = Web.unshare_object(self.context, abs_url)
+            Web.unshare_object(self.context, abs_url, return_type=return_type)
 
         self.ensure_property("EncodedAbsUrl", _property_resolved)
-        return result.value
+        return return_type
 
     def get_sharing_information(self):
         """
@@ -226,14 +276,15 @@ class ListItem(SecurableObject):
         return self
 
     def get_comments(self):
-        comments = CommentCollection(self.context)
-        qry = ServiceOperationQuery(self, "GetComments", [], None, None, comments)
+        """Retrieve ListItem comments"""
+        return_type = CommentCollection(self.context)
+        qry = ServiceOperationQuery(self, "GetComments", [], None, None, return_type)
         self.context.add_query(qry)
-        return comments
+        return return_type
 
     def parse_and_set_field_value(self, field_name, value):
         """Sets the value of the field (2) for the list item based on an implementation-specific transformation
-           of the value..
+           of the value.
            :param str field_name: Specifies the field internal name.
            :param str value: Specifies the new value for the field (2).
 
@@ -275,10 +326,10 @@ class ListItem(SecurableObject):
     @property
     def attachment_files(self):
         """Specifies the collection of attachments that are associated with the list item.<62>"""
-        from office365.sharepoint.attachments.attachmentfile_collection import AttachmentFileCollection
+        from office365.sharepoint.attachments.collection import AttachmentCollection
         return self.properties.get("AttachmentFiles",
-                                   AttachmentFileCollection(self.context,
-                                                            ResourcePath("AttachmentFiles", self.resource_path)))
+                                   AttachmentCollection(self.context,
+                                                        ResourcePath("AttachmentFiles", self.resource_path)))
 
     @property
     def content_type(self):
@@ -302,6 +353,8 @@ class ListItem(SecurableObject):
     @property
     def comments_disabled(self):
         """
+        Indicates whether comments for this item are disabled or not.
+
         :rtype: bool or None
         """
         return self.properties.get("CommentsDisabled", None)
@@ -310,6 +363,7 @@ class ListItem(SecurableObject):
     def file_system_object_type(self):
         """
         Gets a value that specifies whether the list item is a file or a list folder.
+
         :rtype: str or None
         """
         return self.properties.get("FileSystemObjectType", None)
@@ -318,15 +372,19 @@ class ListItem(SecurableObject):
     def id(self):
         """
         Gets a value that specifies the list item identifier.
+
         :rtype: int
         """
         return self.properties.get("Id", None)
 
+    @property
+    def compliance_info(self):
+        return self.properties.get("ComplianceInfo", ListItemComplianceInfo())
+
     @property
     def liked_by_information(self):
         """
         Gets a value that specifies the list item identifier.
-        :rtype: LikedByInformation
         """
         return self.properties.get("LikedByInformation",
                                    LikedByInformation(self.context,
@@ -344,6 +402,7 @@ class ListItem(SecurableObject):
             property_mapping = {
                 "AttachmentFiles": self.attachment_files,
                 "ContentType": self.content_type,
+                "ComplianceInfo": self.compliance_info,
                 "EffectiveBasePermissions": self.effective_base_permissions,
                 "LikedByInformation": self.liked_by_information,
                 "ParentList": self.parent_list,
@@ -377,7 +436,7 @@ class ListItem(SecurableObject):
 
         # fallback: create a new resource path
         if self._resource_path is None:
-            if name == "Id" and self._parent_collection is not None:
+            if name == "Id":
                 self._resource_path = ServiceOperationPath(
                     "getItemById", [value], self._parent_collection.resource_path.parent)
         return self
