@@ -8,10 +8,10 @@ from office365.sharepoint.changes.query import ChangeQuery
 from office365.sharepoint.changes.token import ChangeToken
 from office365.sharepoint.contenttypes.collection import ContentTypeCollection
 from office365.sharepoint.customactions.element import CustomActionElementCollection
-from office365.sharepoint.eventreceivers.definition import EventReceiverDefinitionCollection
+from office365.sharepoint.eventreceivers.definition_collection import EventReceiverDefinitionCollection
 from office365.sharepoint.fields.collection import FieldCollection
 from office365.sharepoint.fields.related_field_collection import RelatedFieldCollection
-from office365.sharepoint.files.checkedOutFileCollection import CheckedOutFileCollection
+from office365.sharepoint.files.checked_out_file_collection import CheckedOutFileCollection
 from office365.sharepoint.files.file import File
 from office365.sharepoint.flows.synchronization_result import FlowSynchronizationResult
 from office365.sharepoint.folders.folder import Folder
@@ -23,7 +23,7 @@ from office365.sharepoint.listitems.listitem import ListItem
 from office365.sharepoint.listitems.collection import ListItemCollection
 from office365.sharepoint.lists.creatables_info import CreatablesInfo
 from office365.sharepoint.lists.data_source import ListDataSource
-from office365.sharepoint.lists.list_rule import SPListRule
+from office365.sharepoint.lists.rule import SPListRule
 from office365.sharepoint.pages.wiki_page_creation_information import WikiPageCreationInformation
 from office365.sharepoint.permissions.securable_object import SecurableObject
 from office365.sharepoint.principal.user import User
@@ -454,6 +454,15 @@ class List(SecurableObject):
         """
         return self.properties.get("BaseType", None)
 
+    @property
+    def default_display_form_url(self):
+        """
+        Specifies the location of the default display form for the list.
+
+        :rtype: str or None
+        """
+        return self.properties.get("DefaultDisplayFormUrl", None)
+
     @property
     def crawl_non_default_views(self):
         """
@@ -558,6 +567,14 @@ class List(SecurableObject):
                                    ContentTypeCollection(self.context,
                                                          ResourcePath("ContentTypes", self.resource_path), self))
 
+    @property
+    def content_types_enabled(self):
+        """Specifies whether content types are enabled for the list.
+
+        :rtype: bool or None
+        """
+        return self.properties.get('ContentTypesEnabled', None)
+
     @property
     def user_custom_actions(self):
         """Gets the User Custom Actions that are associated with the list."""
