@@ -1,15 +1,20 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path import ResourcePath
+from office365.runtime.queries.service_operation import ServiceOperationQuery
+from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.principal.principal import Principal
 from office365.sharepoint.utilities.principal_info import PrincipalInfo
 
 
 class Group(Principal):
-    """Represents a collection of users in a SharePoint site. A group is a type of SP.Principal."""
+    """Represents a collection of members in a SharePoint site. A group is a type of SP.Principal."""
 
     def expand_to_principals(self, max_count=10):
+        """
+        Expands current group to a collection of principals.
+
+        :param int max_count: Specifies the maximum number of principals to be returned.
+        """
         return_type = ClientResult(self.context, ClientValueCollection(PrincipalInfo))
 
         def _group_loaded():
@@ -54,6 +59,6 @@ class Group(Principal):
 
     @property
     def users(self):
-        """Gets a collection of user objects that represents all of the users in the group."""
+        """Gets a collection of user objects that represents all of the members in the group."""
         from office365.sharepoint.principal.user_collection import UserCollection
         return self.properties.get('Users', UserCollection(self.context, ResourcePath("Users", self.resource_path)))
