@@ -1,6 +1,6 @@
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.sharepoint.alerts.alert_collection import AlertCollection
+from office365.sharepoint.alerts.collection import AlertCollection
 from office365.sharepoint.principal.principal import Principal
 from office365.sharepoint.principal.user_id_info import UserIdInfo
 
@@ -19,18 +19,12 @@ class User(Principal):
             person_props = people_manager.get_properties_for(self.login_name)
 
             def _person_props_loaded(resp):
-                site.set_property("NewSiteUrl", person_props.properties['PersonalUrl'])
+                site.set_property("__siteUrl", person_props.personal_url)
             self.context.after_execute(_person_props_loaded)
 
         self.ensure_property("LoginName", _user_loaded)
         return site
 
-    def get(self):
-        """
-        :rtype: User
-        """
-        return super(User, self).get()
-
     @property
     def groups(self):
         """Gets a collection of group objects that represents all of the groups for the user."""
@@ -40,12 +34,13 @@ class User(Principal):
 
     @property
     def alerts(self):
+        """Gets site alerts for this user."""
         return self.properties.get('Alerts',
                                    AlertCollection(self.context, ResourcePath("Alerts", self.resource_path)))
 
     @property
     def is_site_admin(self):
-        """Gets or sets a Boolean value that specifies whether the user is a site collection administrator."""
+        """Gets a Boolean value that specifies whether the user is a site collection administrator."""
         return self.properties.get('isSiteAdmin', None)
 
     @property
@@ -54,7 +49,25 @@ class User(Principal):
          user's name identifier."""
         return self.properties.get('UserId', UserIdInfo())
 
+    @property
+    def email(self):
+        """
+        Specifies the e-mail address of the user.
+        It MUST NOT be NULL. Its length MUST be equal to or less than 255.
+
+        :rtype: str or None
+        """
+        return self.properties.get('Email', None)
+
     def expire(self):
         qry = ServiceOperationQuery(self, "Expire")
         self.context.add_query(qry)
         return self
+
+    def get_property(self, name, default_value=None):
+        if default_value is None:
+            property_mapping = {
+                "UserId": self.user_id,
+            }
+            default_value = property_mapping.get(name, None)
+        return super(User, self).get_property(name, default_value)
