@@ -2,7 +2,7 @@ from office365.runtime.client_result import ClientResult
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.search.simpleDataTable import SimpleDataTable
+from office365.sharepoint.search.simple_data_table import SimpleDataTable
 
 
 class DocumentCrawlLog(BaseEntity):
@@ -10,9 +10,8 @@ class DocumentCrawlLog(BaseEntity):
     about items that were crawled."""
 
     def __init__(self, context):
-        super(DocumentCrawlLog, self).__init__(context,
-                                               ResourcePath(
-                                                   "Microsoft.SharePoint.Client.Search.Administration.DocumentCrawlLog"))
+        static_path = ResourcePath("Microsoft.SharePoint.Client.Search.Administration.DocumentCrawlLog")
+        super(DocumentCrawlLog, self).__init__(context,static_path)
 
     def get_crawled_urls(self, get_count_only=False):
         """
