@@ -1,15 +1,11 @@
 from office365.runtime.client_result import ClientResult
-from office365.runtime.client_value import ClientValue
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.permissions.role_definition import RoleDefinition
+from office365.sharepoint.permissions.roles.definitions.definition import RoleDefinition
 from office365.sharepoint.sharing.user_role_assignment import UserRoleAssignment
 from office365.sharepoint.sharing.user_sharing_result import UserSharingResult
-
-
-class SharedWithMeViewItemRemovalResult(ClientValue):
-    pass
+from office365.sharepoint.userprofiles.sharedwithme.view_item_removal_result import SharedWithMeViewItemRemovalResult
 
 
 class DocumentSharingManager(BaseEntity):
