@@ -1,97 +1,48 @@
 from office365.runtime.client_result import ClientResult
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.audit.audit import Audit
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.changes.change_collection import ChangeCollection
-from office365.sharepoint.eventreceivers.event_receiver_definition import EventReceiverDefinitionCollection
-from office365.sharepoint.features.feature_collection import FeatureCollection
+from office365.sharepoint.changes.collection import ChangeCollection
+from office365.sharepoint.changes.token import ChangeToken
+from office365.sharepoint.eventreceivers.definition_collection import EventReceiverDefinitionCollection
+from office365.sharepoint.features.collection import FeatureCollection
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.portal.site_icon_manager import SiteIconManager
-from office365.sharepoint.portal.site_status import SiteStatus
 from office365.sharepoint.principal.user import User
-from office365.sharepoint.publishing.communication_site import CommunicationSiteCreationRequest
 from office365.sharepoint.recyclebin.item_collection import RecycleBinItemCollection
-from office365.sharepoint.sites.site_health_summary import SiteHealthSummary
+from office365.sharepoint.sitehealth.summary import SiteHealthSummary
 from office365.sharepoint.sites.sph_site import SPHSite
 from office365.sharepoint.sites.usage_info import UsageInfo
-from office365.sharepoint.usercustomactions.user_custom_action_collection import UserCustomActionCollection
+from office365.sharepoint.usercustomactions.collection import UserCustomActionCollection
 from office365.sharepoint.webs.web import Web
-from office365.sharepoint.webs.web_template_collection import WebTemplateCollection
+from office365.sharepoint.webs.template_collection import WebTemplateCollection
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
 
 
 class Site(BaseEntity):
     """Represents a collection of sites in a Web application, including a top-level website and all its sub sites."""
 
-    def __init__(self, context):
-        super(Site, self).__init__(context, ResourcePath("Site", None))
+    def __init__(self, context, resource_path=None):
+        super(Site, self).__init__(context, ResourcePath("Site", resource_path))
 
-    @staticmethod
-    def create_communication_site(root_site_url, alias, title):
-        """
-        Creates a modern SharePoint Communication site
-
-        :param str root_site_url: Tenant root site url, e.g. https://contoso.sharepoint.com
-        :param str alias: Site alias which defines site url, e.g. https://contoso.sharepoint.com/sites/{alias}
-        :param str title: Site title
-        """
-
-        site = Site.from_url(root_site_url).get()  # type: Site
-        ctx = site.context
-
-        def _before_site_create(resp):
-            site_url = f"{root_site_url}sites/{alias}"
-            request = CommunicationSiteCreationRequest(title, site_url)
-            result = ctx.site_pages.communication_site.create(request)
-
-            def _after_site_create(site_create_resp):
-                if result.value.SiteStatus == SiteStatus.Error:
-                    raise ValueError("Site creation error")
-                elif result.value.SiteStatus == SiteStatus.Ready:
-                    site.set_property("NewSiteUrl", result.value.SiteUrl)
-            ctx.after_execute(_after_site_create)
-
-        ctx.after_execute(_before_site_create)
-        return site
-
-    @staticmethod
-    def create_team_site(root_site_url, alias, title, is_public=True):
-        """Creates a modern SharePoint Team site
-
-        :param str root_site_url: Tenant root site url, e.g. https://contoso.sharepoint.com
-        :param str alias: Site alias which defines site url, e.g. https://contoso.sharepoint.com/teams/{alias}
-        :param str title: Site title
-        """
-        from office365.sharepoint.client_context import ClientContext
-        ctx = ClientContext(root_site_url)
-        site = ctx.site.get()
-
-        def _before_site_create(resp):
-            from office365.sharepoint.portal.group_site_manager import GroupSiteManager
-            site_manager = GroupSiteManager(ctx)
-            result = site_manager.create_group_ex(title, alias, is_public, None)
-
-            def _after_site_create(site_create_resp):
-                if result.value.SiteStatus == SiteStatus.Error:
-                    raise ValueError(result.value.ErrorMessage)
-                elif result.value.SiteStatus == SiteStatus.Ready:
-                    site.set_property("NewSiteUrl", result.value.SiteUrl)
-            ctx.after_execute(_after_site_create)
-
-        ctx.after_execute(_before_site_create)
-        return site
+    def delete_object(self):
+        """Deletes a site"""
+        def _site_resolved():
+            self.context.group_site_manager.delete(self.url)
+        self.ensure_property("Url", _site_resolved)
+        return self
 
     @staticmethod
     def from_url(url):
-        """Construct and return a site instance
+        """
+        Initiates and returns a site instance
 
         :type url: str
         """
         from office365.sharepoint.client_context import ClientContext
-        client = ClientContext(url)
-        return client.site
+        return ClientContext(url).site
 
     def get_site_logo(self):
         """
@@ -116,6 +67,9 @@ class Site(BaseEntity):
         return self
 
     def is_valid_home_site(self):
+        """
+        Determines whether a site is landing site for your intranet.
+        """
         return_type = ClientResult(self.context)
 
         def _site_loaded():
@@ -125,6 +79,9 @@ class Site(BaseEntity):
         return return_type
 
     def set_as_home_site(self):
+        """
+        Sets a site as a landing site for your intranet.
+        """
         result = ClientResult(self.context)
 
         def _site_loaded():
@@ -137,7 +94,7 @@ class Site(BaseEntity):
         """Returns the collection of all changes from the change log that have occurred within the scope of the site,
         based on the specified query.
 
-        :param office365.sharepoint.changes.change_query.ChangeQuery query: Specifies which changes to return
+        :param office365.sharepoint.changes.query.ChangeQuery query: Specifies which changes to return
         """
         changes = ChangeCollection(self.context)
         qry = ServiceOperationQuery(self, "getChanges", None, query, "query", changes)
@@ -318,10 +275,21 @@ class Site(BaseEntity):
         """
         Disables the hub site feature on a site.
         """
-        qry = ServiceOperationQuery(self, "UnRegisterHubSite", None, None, None, None)
+        qry = ServiceOperationQuery(self, "UnRegisterHubSite")
         self.context.add_query(qry)
         return self
 
+    @property
+    def allow_designer(self):
+        """
+        Specifies whether a designer can be used on this site collection.
+        See Microsoft.SharePoint.Client.Web.AllowDesignerForCurrentUser, which is the scalar property used
+        to determine the behavior for the current user. The default, if not disabled on the Web application, is "true".
+
+        :rtype: bool or None
+        """
+        return self.properties.get("AllowDesigner", None)
+
     @property
     def audit(self):
         """
@@ -329,6 +297,37 @@ class Site(BaseEntity):
         """
         return self.properties.get("Audit", Audit(self.context, ResourcePath("Audit", self.resource_path)))
 
+    @property
+    def can_upgrade(self):
+        """
+        Specifies whether this site collection is in an implementation-specific valid state for site collection upgrade,
+         "true" if it is; otherwise, "false".
+
+        :rtype: bool
+        """
+        return self.properties.get("CanUpgrade", None)
+
+    @property
+    def classification(self):
+        """
+        Gets the classification of this site.
+
+        :rtype: str or None
+        """
+        return self.properties.get("Classification", None)
+
+    @property
+    def current_change_token(self):
+        """Gets the current change token that is used in the change log for the site collection."""
+        return self.properties.get("CurrentChangeToken", ChangeToken())
+
+    @property
+    def group_id(self):
+        """
+        :rtype: str or None
+        """
+        return self.properties.get("GroupId", None)
+
     @property
     def root_web(self):
         """Get root web"""
@@ -337,7 +336,7 @@ class Site(BaseEntity):
     @property
     def owner(self):
         """Gets or sets the owner of the site collection. (Read-only in sandboxed solutions.)"""
-        return self.properties.get('owner', User(self.context, ResourcePath("owner", self.resource_path)))
+        return self.properties.get('Owner', User(self.context, ResourcePath("Owner", self.resource_path)))
 
     @property
     def read_only(self):
@@ -352,6 +351,9 @@ class Site(BaseEntity):
     @property
     def required_designer_version(self):
         """
+        Specifies the required minimum version of the designer that can be used on this site collection.
+        The default, if not disabled on the Web application, is "15.0.0.0".
+
         :rtype: str
         """
         return self.properties.get("RequiredDesignerVersion", None)
@@ -365,6 +367,7 @@ class Site(BaseEntity):
         """
         return self.properties.get('Url', None)
 
+    @property
     def server_relative_url(self):
         """
         Specifies the server-relative URL of the top-level site in the site collection.
@@ -373,6 +376,31 @@ class Site(BaseEntity):
         """
         return self.properties.get("ServerRelativeUrl", None)
 
+    @property
+    def share_by_email_enabled(self):
+        """
+        When true, users will be able to grant permissions to guests for resources within the site collection.
+
+        :rtype: bool or none
+        """
+        return self.properties.get('ShareByEmailEnabled', None)
+
+    @property
+    def trim_audit_log(self):
+        """
+        When this flag is set for the site, the audit events are trimmed periodically.
+
+        :rtype: bool or none
+        """
+        return self.properties.get('TrimAuditLog', None)
+
+    @property
+    def write_locked(self):
+        """
+        :rtype: bool or none
+        """
+        return self.properties.get('WriteLocked', None)
+
     @property
     def id(self):
         """
@@ -392,6 +420,8 @@ class Site(BaseEntity):
     @property
     def is_hub_site(self):
         """
+        Returns whether the specified site is a hub site
+
         :rtype: bool
         """
         return self.properties.get("IsHubSite", None)
@@ -449,6 +479,7 @@ class Site(BaseEntity):
     def get_property(self, name, default_value=None):
         if default_value is None:
             property_mapping = {
+                "CurrentChangeToken": self.current_change_token,
                 "EventReceivers": self.event_receivers,
                 "RecycleBin": self.recycle_bin,
                 "RootWeb": self.root_web,
@@ -460,9 +491,9 @@ class Site(BaseEntity):
         return super(Site, self).get_property(name, default_value)
 
     def set_property(self, name, value, persist_changes=True):
-        super(Site, self).set_property(name, value, persist_changes)
-        if name == "NewSiteUrl":
-            safe_url = value[:-1] if value[-1] == "/" else value
-            super(Site, self).set_property("Url", safe_url)
-            self._context = self.context.clone(safe_url)
+        if name == "__siteUrl":
+            super(Site, self).set_property("Url", value)
+            self._context = self.context.clone(value)
+        else:
+            super(Site, self).set_property(name, value, persist_changes)
         return self
